Crate lance_core

Crate lance_core 

Re-exports

pub use error::ArrowResult;
pub use error::Error;
pub use error::FenceReason;
pub use error::Result;
pub use error::box_error;

Modules

cache
Lance cache system.
container
datatypes
Lance data types, Schema and Field
deepsize
error
levenshtein
traits
Dataset Traits
utils

Macros

assume
Assert an invariant that should also be visible to the optimizer.
assume_eq
Helper macro for equality assumptions.

Constants

ROW_ADDR
Column name for the meta row address.
ROW_CREATED_AT_VERSION
Column name for the row’s created at dataset version.
ROW_ID
Column name for the meta row ID.
ROW_LAST_UPDATED_AT_VERSION
Column name for the row’s last updated at dataset version.
ROW_OFFSET
Column name for the meta row offset.
WILDCARD
Wildcard to indicate all non-system columns

Statics

ROW_ADDR_FIELD
Row address field. This is nullable because its validity bitmap is sometimes used as a selection vector.
ROW_CREATED_AT_VERSION_FIELD
Row created at version field.
ROW_ID_FIELD
Row ID field. This is nullable because its validity bitmap is sometimes used as a selection vector.
ROW_LAST_UPDATED_AT_VERSION_FIELD
Row last updated at version field.
ROW_OFFSET_FIELD
Row offset field. This is nullable merely for compatibility with the other fields.

Functions

is_system_column
Check if a column name is a system column.