pub fn build_from_config(
config: &BackendConfig,
) -> Result<Arc<dyn CacheBackend>>Expand description
Look up the constructor for config.kind and build a backend.
Returns Err if no backend has been registered under that identifier.
pub fn build_from_config(
config: &BackendConfig,
) -> Result<Arc<dyn CacheBackend>>Look up the constructor for config.kind and build a backend.
Returns Err if no backend has been registered under that identifier.