pub struct CacheStats {
pub hits: u64,
pub misses: u64,
pub num_entries: usize,
pub size_bytes: usize,
}Fields
hits: u64Number of times get, get_unsized, or get_or_insert found an item in the cache.
misses: u64Number of times get, get_unsized, or get_or_insert did not find an item in the cache.
num_entries: usizeNumber of entries currently in the cache.
size_bytes: usizeTotal size in bytes of all entries in the cache.
Implementations
Sourceimpl CacheStats
impl CacheStats