pub struct WeakLanceCache { /* private fields */ }Expand description
A weak reference to a LanceCache, used by indices to avoid circular references. When the original cache is dropped, operations on this will gracefully no-op.
Implementations
Sourceimpl WeakLanceCache
impl WeakLanceCache
pub fn from(cache: &LanceCache) -> Self
pub fn with_key_prefix(&self, prefix: &str) -> Self
pub async fn get_with_key<K>(&self, cache_key: &K) -> Option<Arc<K::ValueType>>
pub async fn insert_with_key<K>( &self, cache_key: &K, value: Arc<K::ValueType>, ) -> bool
Sourcepub async fn get_or_insert_with_key<K, F, Fut>(
&self,
cache_key: K,
loader: F,
) -> Result<Arc<K::ValueType>>
pub async fn get_or_insert_with_key<K, F, Fut>( &self, cache_key: K, loader: F, ) -> Result<Arc<K::ValueType>>
Get or insert an item, computing it if necessary.
Deduplication of concurrent loads is handled by the backend.
pub async fn get_unsized_with_key<K>( &self, cache_key: &K, ) -> Option<Arc<K::ValueType>>
pub async fn insert_unsized_with_key<K>( &self, cache_key: &K, value: Arc<K::ValueType>, )