pub struct CloneableError(pub Error);Expand description
Wrap an error in a new error type that implements Clone
This is useful when two threads/streams share a common fallible source Definite not-found errors preserve typed source-chain detection and their human-readable representation. Timeout and I/O errors preserve their error categories. Other cloned results use Error::Cloned with the string representation of the base error.
Tuple Fields
0: ErrorTrait Implementations