pub struct FieldNotFoundError {
pub field_name: String,
pub candidates: Vec<String>,
}Expand description
Error for when a requested field is not found in a schema.
This error computes suggestions lazily (only when displayed) to avoid computing Levenshtein distance when the error is created but never shown.
Fields
field_name: Stringcandidates: Vec<String>Trait Implementations
Sourceimpl Debug for FieldNotFoundError
impl Debug for FieldNotFoundError
Sourceimpl Display for FieldNotFoundError
impl Display for FieldNotFoundError
Sourceimpl Error for FieldNotFoundError
impl Error for FieldNotFoundError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl From<FieldNotFoundError> for Error
impl From<FieldNotFoundError> for Error
Sourcefn from(error: FieldNotFoundError) -> Self
fn from(error: FieldNotFoundError) -> Self
Converts to this type from the input type.