pub trait LanceOptionExt<T> { // Required method fn expect_ok(self) -> Result<T>; }
Unwraps an option, returning an internal error if the option is None.
Can be used when an option is expected to have a value.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".