assume

Macro assume 

macro_rules! assume {
    ($cond:expr) => { ... };
    ($cond:expr, $($arg:tt)+) => { ... };
}
Assert an invariant that should also be visible to the optimizer.

Unlike debug_assert!, this remains checked in release builds. This is required because the macro can be invoked from safe Rust and an invalid assumption must not become undefined behavior.