Module cpu

Module cpu 

Structs

SimdInfo
Snapshot of the SIMD tier lance dispatches to on the current host, plus the raw CPU features detected for diagnostic purposes.

Enums

SimdSupport
A level of SIMD support for some feature.

Statics

SIMD_SUPPORT
Support for SIMD operations

Functions

simd_info
Returns a snapshot of the SIMD tier lance is using on this host along with the raw CPU feature flags that drove the decision.