Module futures

Module futures 

Structs

FinallyStream
OnDropStream
A stream wrapper that calls a function when dropped.
SharedStream
A stream that can be shared between two consumers.

Enums

Capacity
A potentially unbounded capacity

Traits

FinallyStreamExt
SharedStreamExt
StreamOnDropExt