Module mask

Module mask 

Structs

NullableRowAddrSet
A set of row ids, with optional set of nulls.
RowAddrTreeMap
A collection of row addresses.
RowIdSet
A set of stable row ids backed by a 64-bit Roaring bitmap.

Enums

NullableRowAddrMask
A version of RowAddrMask that supports nulls.
RowAddrMask
A mask that selects or deselects rows based on an allow-list or block-list.
RowAddrSelection
RowIdMask
A mask over stable row ids based on an allow-list or block-list.

Traits

RowSetOps
Common operations over a set of rows (either row ids or row addresses).

Functions

bitmap_to_ranges
ranges_to_bitmap