pub enum RowIdMask {
AllowList(RowIdSet),
BlockList(RowIdSet),
}Expand description
A mask over stable row ids based on an allow-list or block-list.
The semantics mirror RowAddrMask, but operate on stable
row ids instead of physical row addresses.
Variants
AllowList(RowIdSet)
Only the ids in the set are selected.
BlockList(RowIdSet)
All ids are selected except those in the set.
Implementations
Sourceimpl RowIdMask
impl RowIdMask
Sourcepub fn allow_nothing() -> Self
pub fn allow_nothing() -> Self
Create a mask that doesn’t allow any row id.
Sourcepub fn from_allowed(allow_list: RowIdSet) -> Self
pub fn from_allowed(allow_list: RowIdSet) -> Self
Create a mask from an allow list.
Sourcepub fn from_block(block_list: RowIdSet) -> Self
pub fn from_block(block_list: RowIdSet) -> Self
Create a mask from a block list.
Sourcepub fn selected(&self, row_id: u64) -> bool
pub fn selected(&self, row_id: u64) -> bool
True if the row id is selected by the mask, false otherwise.
Sourcepub fn selected_indices<'a>(
&self,
row_ids: impl Iterator<Item = &'a u64> + 'a,
) -> Vec<u64>
pub fn selected_indices<'a>( &self, row_ids: impl Iterator<Item = &'a u64> + 'a, ) -> Vec<u64>
Return the indices of the input row ids that are selected by the mask.
Sourcepub fn also_block(self, block_list: RowIdSet) -> Self
pub fn also_block(self, block_list: RowIdSet) -> Self
Also block the given ids.
AllowList(a)->AllowList(a \\ block_list)BlockList(b)->BlockList(b union block_list)
Sourcepub fn also_allow(self, allow_list: RowIdSet) -> Self
pub fn also_allow(self, allow_list: RowIdSet) -> Self
Also allow the given ids.
AllowList(a)->AllowList(a union allow_list)BlockList(b)->BlockList(b \\ allow_list)