RowIdSet

Struct RowIdSet 

pub struct RowIdSet { /* private fields */ }
A set of stable row ids backed by a 64-bit Roaring bitmap.

This is a thin wrapper around RoaringTreemap. It represents a collection of unique row ids and provides the common row-set operations defined by RowSetOps.

Implementations

Source

impl RowIdSet

pub fn new() -> Self

Creates an empty set of row ids.

pub fn iter(&self) -> impl Iterator<Item = u64> + '_

Returns an iterator over the contained row ids in ascending order.

pub fn union(self, other: &Self) -> Self

Returns the union of self and other.

pub fn difference(self, other: &Self) -> Self

Returns the set difference self \\ other.