pub struct TempFile { /* private fields */ }Expand description
A temporary file
This is a wrapper around tempfile::NamedTempFile. The file will normally be cleaned
up when the object is dropped.
Note: this function may create an empty file when the object is created. If you are checking
that the path does not exist, you should use TempStdPath instead.
Implementations