pub struct RowIdSet { /* private fields */ }Expand description
A set of stable row ids backed by a 64-bit Roaring bitmap.
This is a thin wrapper around RoaringTreemap. It represents a
collection of unique row ids and provides the common row-set
operations defined by RowSetOps.
Implementations