ProxyObjectStore

Struct ProxyObjectStore 

pub struct ProxyObjectStore { /* private fields */ }
A proxy object store

This store wraps another object store and applies the given policy to all calls made to the underlying store. This can be used to simulate failures or, perhaps in the future, to mock out results or provide other fine-grained control.

Implementations

Source

impl ProxyObjectStore

pub fn new( target: Arc<dyn ObjectStore>, policy: Arc<Mutex<ProxyObjectStorePolicy>>, ) -> Self